package net.daum.mobilead;

import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.graphics.Rect;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.Log;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.RelativeLayout.LayoutParams;
import android.widget.TextView;
import net.daum.mobilead.protocol.AdCommon;
import net.daum.mobilead.protocol.AdRefreshTask;
import net.daum.mobilead.protocol.AdTHttpContext;
import net.daum.mobilead.protocol.AdWebView;
import net.daum.mobilead.protocol.AdWebViewClient;
import net.daum.mobilead.protocol.MobileAd;
import net.daum.mobilead.protocol.MobileAdSDKError;
import org.apache.http.util.ByteArrayBuffer;

public class MobileAdView extends RelativeLayout
{
  private static final int AD_HEIGHT_DP = 48;
  private static final int AD_WIDTH_DP = 320;
  private final int DEFAULT_REFRESH_INTERVAL = 60;
  private final int GRAND_MARGIN = 24;
  private final int HALF = 18;
  private final int ICONIMG_SIZE = 38;
  private final int LARGE_MARGIN = 7;
  private final int MAXINTERVAL = 120;
  private final int MININTERVAL = 12;
  private final int SMALL_MARGIN = 5;
  private final int TYPEIMG_SIZE = 27;
  private AdRefreshTask adRefreshTask;
  private boolean hasAd = 0;
  private String mAdBackgroundColor;
  private AdHttpListener mAdListener = null;
  private TextView mAdText = null;
  private String mAdTextColor;
  private RelativeLayout mBannerAdLayout = null;
  private ImageView mBannerImage = null;
  private String mClickURL = null;
  private RelativeLayout mHtmlAdLayout = null;
  private AdWebView mHtmlWebView = null;
  private AdWebViewClient mHtmlWebViewClient = null;
  private ImageView mIconImage = null;
  private int mRefreshInterval = 60;
  private String mTURL = null;
  private RelativeLayout mTextAdLayout = null;
  private ImageView mTextTypeImage = null;
  private int textviewH = 0;
  private int textviewW = 0;
  private String userAgent = null;

  public MobileAdView(Context paramContext)
  {
    this(paramContext, null, 0);
  }

  public MobileAdView(Context paramContext, AttributeSet paramAttributeSet)
  {
    this(paramContext, paramAttributeSet, 0);
  }

  public MobileAdView(Context paramContext, AttributeSet paramAttributeSet, int paramInt)
  {
    super(paramContext, paramAttributeSet, paramInt);
    if (paramAttributeSet != null)
      setAttribute(paramContext, paramAttributeSet);
    initView();
    MobileAdView.1 local1 = new MobileAdView.1(this);
    AdRefreshTask localAdRefreshTask = new AdRefreshTask(this, local1);
    this.adRefreshTask = localAdRefreshTask;
  }

  private void changedAd(String paramString1, String paramString2)
  {
    this.mClickURL = paramString1;
    this.mTURL = paramString2;
    if (this.mAdListener != null)
      this.mAdListener.didDownloadAd_AdListener();
  }

  private void destroyBannerAdLayout()
  {
    if (this.mBannerAdLayout != null)
    {
      this.mBannerAdLayout.setVisibility(8);
      this.mBannerImage = null;
      this.mBannerAdLayout = null;
    }
  }

  private void destroyHtmlAdLasyout()
  {
    if (this.mHtmlAdLayout != null)
    {
      this.mHtmlAdLayout.setVisibility(8);
      this.mHtmlWebViewClient = null;
      if (this.mHtmlWebView != null)
      {
        this.mHtmlWebView.destroy();
        this.mHtmlWebView = null;
      }
      this.mHtmlAdLayout = null;
    }
  }

  private void destroyTextAdLayout()
  {
    if (this.mTextAdLayout != null)
    {
      this.mTextAdLayout.setVisibility(8);
      this.mAdBackgroundColor = null;
      this.mIconImage = null;
      this.mTextTypeImage = null;
      this.mAdTextColor = null;
      this.mAdText = null;
      this.mTextAdLayout = null;
    }
  }

  private Drawable imageFromDaumAd(ByteArrayBuffer paramByteArrayBuffer)
  {
    BitmapDrawable localBitmapDrawable = null;
    if ((paramByteArrayBuffer != null) && (paramByteArrayBuffer.length() > 0))
    {
      byte[] arrayOfByte = paramByteArrayBuffer.toByteArray();
      int i = arrayOfByte.length;
      Bitmap localBitmap = BitmapFactory.decodeByteArray(arrayOfByte, 0, i);
      if (localBitmap != null)
      {
        Resources localResources = getContext().getResources();
        localBitmapDrawable = new BitmapDrawable(localResources, localBitmap);
      }
    }
    return localBitmapDrawable;
  }

  private void initBannerAd()
  {
    Context localContext1 = getContext();
    RelativeLayout localRelativeLayout1 = new RelativeLayout(localContext1);
    this.mBannerAdLayout = localRelativeLayout1;
    this.mBannerAdLayout.setGravity(17);
    RelativeLayout localRelativeLayout2 = this.mBannerAdLayout;
    int i = pixelFromDp(48);
    RelativeLayout.LayoutParams localLayoutParams1 = new RelativeLayout.LayoutParams(-1, i);
    addView(localRelativeLayout2, localLayoutParams1);
    Context localContext2 = getContext();
    ImageView localImageView1 = new ImageView(localContext2);
    this.mBannerImage = localImageView1;
    RelativeLayout localRelativeLayout3 = this.mBannerAdLayout;
    ImageView localImageView2 = this.mBannerImage;
    int j = pixelFromDp(320);
    int k = pixelFromDp(48);
    RelativeLayout.LayoutParams localLayoutParams2 = new RelativeLayout.LayoutParams(j, k);
    localRelativeLayout3.addView(localImageView2, localLayoutParams2);
    ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mBannerAdLayout.getLayoutParams()).addRule(3);
  }

  private void initHtmlAd()
  {
    Context localContext = getContext();
    RelativeLayout localRelativeLayout1 = new RelativeLayout(localContext);
    this.mHtmlAdLayout = localRelativeLayout1;
    this.mHtmlAdLayout.setGravity(17);
    RelativeLayout localRelativeLayout2 = this.mHtmlAdLayout;
    int i = pixelFromDp(48);
    RelativeLayout.LayoutParams localLayoutParams = new RelativeLayout.LayoutParams(-1, i);
    addView(localRelativeLayout2, localLayoutParams);
    RelativeLayout localRelativeLayout3 = this.mHtmlAdLayout;
    AdWebViewClient localAdWebViewClient = new AdWebViewClient(localRelativeLayout3);
    this.mHtmlWebViewClient = localAdWebViewClient;
  }

  private void initTextAd()
  {
    float f = getContext().getResources().getDisplayMetrics().density;
    int i = getContext().getResources().getDisplayMetrics().widthPixels;
    Context localContext1 = getContext();
    RelativeLayout localRelativeLayout1 = new RelativeLayout(localContext1);
    this.mTextAdLayout = localRelativeLayout1;
    this.mTextAdLayout.setGravity(17);
    if (this.mAdBackgroundColor != null)
    {
      RelativeLayout localRelativeLayout2 = this.mTextAdLayout;
      int j = Color.parseColor(this.mAdBackgroundColor);
      localRelativeLayout2.setBackgroundColor(j);
    }
    RelativeLayout localRelativeLayout3 = this.mTextAdLayout;
    int k = pixelFromDp(48);
    RelativeLayout.LayoutParams localLayoutParams1 = new RelativeLayout.LayoutParams(-1, k);
    addView(localRelativeLayout3, localLayoutParams1);
    Context localContext2 = getContext();
    ImageView localImageView1 = new ImageView(localContext2);
    this.mIconImage = localImageView1;
    int m = (int)(38.0F * f);
    RelativeLayout localRelativeLayout4 = this.mTextAdLayout;
    ImageView localImageView2 = this.mIconImage;
    RelativeLayout.LayoutParams localLayoutParams2 = new RelativeLayout.LayoutParams(m, m);
    localRelativeLayout4.addView(localImageView2, localLayoutParams2);
    Context localContext3 = getContext();
    ImageView localImageView3 = new ImageView(localContext3);
    this.mTextTypeImage = localImageView3;
    int n = (int)(27.0F * f);
    RelativeLayout localRelativeLayout5 = this.mTextAdLayout;
    ImageView localImageView4 = this.mTextTypeImage;
    RelativeLayout.LayoutParams localLayoutParams3 = new RelativeLayout.LayoutParams(n, n);
    localRelativeLayout5.addView(localImageView4, localLayoutParams3);
    Context localContext4 = getContext();
    TextView localTextView1 = new TextView(localContext4);
    this.mAdText = localTextView1;
    this.mAdText.setTextSize(0, 16.0F);
    this.mAdText.setMaxLines(2);
    this.mAdText.setHorizontallyScrolling(0);
    this.mAdText.setTypeface(null, 1);
    if (this.mAdTextColor != null)
    {
      TextView localTextView2 = this.mAdText;
      int i1 = Color.parseColor(this.mAdTextColor);
      localTextView2.setTextColor(i1);
    }
    TextView localTextView3 = this.mAdText;
    int i2 = (int)(38.0F * f);
    localTextView3.setMaxHeight(i2);
    int i3 = ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mTextTypeImage.getLayoutParams()).width;
    int i4 = ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mIconImage.getLayoutParams()).width + i3;
    int i5 = (int)(24.0F * f);
    int i6 = i4 + i5;
    int i7 = i - i6;
    RelativeLayout localRelativeLayout6 = this.mTextAdLayout;
    TextView localTextView4 = this.mAdText;
    RelativeLayout.LayoutParams localLayoutParams4 = new RelativeLayout.LayoutParams(i7, -1);
    localRelativeLayout6.addView(localTextView4, localLayoutParams4);
    ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mIconImage.getLayoutParams()).addRule(9);
    ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mIconImage.getLayoutParams()).addRule(15);
    RelativeLayout.LayoutParams localLayoutParams5 = (RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mIconImage.getLayoutParams();
    int i8 = (int)(5.0F * f);
    localLayoutParams5.leftMargin = i8;
    RelativeLayout.LayoutParams localLayoutParams6 = (RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mIconImage.getLayoutParams();
    int i9 = (int)(7.0F * f);
    localLayoutParams6.rightMargin = i9;
    ImageView localImageView5 = this.mIconImage;
    int i10 = this.mIconImage.hashCode();
    localImageView5.setId(i10);
    RelativeLayout.LayoutParams localLayoutParams7 = (RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mAdText.getLayoutParams();
    int i11 = this.mIconImage.getId();
    localLayoutParams7.addRule(1, i11);
    ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mAdText.getLayoutParams()).addRule(15);
    ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mTextTypeImage.getLayoutParams()).addRule(11);
    ((RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mTextTypeImage.getLayoutParams()).addRule(15);
    RelativeLayout.LayoutParams localLayoutParams8 = (RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mTextTypeImage.getLayoutParams();
    int i12 = (int)(7.0F * f);
    localLayoutParams8.leftMargin = i12;
    RelativeLayout.LayoutParams localLayoutParams9 = (RelativeLayout.LayoutParams)(RelativeLayout.LayoutParams)this.mTextTypeImage.getLayoutParams();
    int i13 = (int)(5.0F * f);
    localLayoutParams9.rightMargin = i13;
  }

  private boolean makeBannerAdView(MobileAd paramMobileAd)
  {
    int i;
    if (this.mBannerAdLayout == null)
      i = 0;
    while (true)
    {
      return i;
      ByteArrayBuffer localByteArrayBuffer1 = paramMobileAd.img();
      Drawable localDrawable1 = imageFromDaumAd(localByteArrayBuffer1);
      if (localDrawable1 != null)
      {
        if (paramMobileAd.bgimg() != null)
        {
          ByteArrayBuffer localByteArrayBuffer2 = paramMobileAd.bgimg();
          Drawable localDrawable2 = imageFromDaumAd(localByteArrayBuffer2);
          this.mBannerAdLayout.setBackgroundDrawable(localDrawable2);
        }
        this.mBannerImage.setBackgroundDrawable(localDrawable1);
        showBannerAdLayout();
        i = 1;
        continue;
      }
      i = 0;
    }
  }

  private boolean makeHtmlAdView(MobileAd paramMobileAd)
  {
    int i;
    if (this.mHtmlAdLayout == null)
      i = 0;
    while (true)
    {
      return i;
      if (paramMobileAd.html() != null)
      {
        Context localContext = getContext();
        AdWebView localAdWebView = new AdWebView(localContext);
        AdWebViewClient localAdWebViewClient1 = this.mHtmlWebViewClient;
        localAdWebView.setWebViewClient(localAdWebViewClient1);
        AdWebViewClient localAdWebViewClient2 = this.mHtmlWebViewClient;
        MobileAdView.3 local3 = new MobileAdView.3(this, paramMobileAd);
        localAdWebViewClient2.setAdChangedHandler(local3);
        String str = paramMobileAd.html();
        localAdWebView.loadData(str, "text/html", "utf8");
        this.mHtmlWebView = localAdWebView;
        i = 1;
        continue;
      }
      i = 0;
    }
  }

  private boolean makeTextAdView(MobileAd paramMobileAd)
  {
    int i;
    if (this.mTextAdLayout == null)
      i = 0;
    while (true)
    {
      return i;
      ByteArrayBuffer localByteArrayBuffer1 = paramMobileAd.img();
      Drawable localDrawable1 = imageFromDaumAd(localByteArrayBuffer1);
      ByteArrayBuffer localByteArrayBuffer2 = paramMobileAd.ctypeimg();
      Drawable localDrawable2 = imageFromDaumAd(localByteArrayBuffer2);
      ByteArrayBuffer localByteArrayBuffer3 = paramMobileAd.bgimg();
      Drawable localDrawable3 = imageFromDaumAd(localByteArrayBuffer3);
      if ((localDrawable1 != null) && (localDrawable2 != null))
      {
        if (paramMobileAd.bgcolor() != null)
        {
          String str1 = paramMobileAd.bgcolor();
          this.mAdBackgroundColor = str1;
        }
        if (paramMobileAd.txcolor() != null)
        {
          String str2 = paramMobileAd.txcolor();
          this.mAdTextColor = str2;
        }
        this.mIconImage.setBackgroundDrawable(localDrawable1);
        this.mTextTypeImage.setBackgroundDrawable(localDrawable2);
        TextView localTextView2 = this.mAdText;
        int k = Color.parseColor(this.mAdTextColor);
        localTextView2.setTextColor(k);
        int m = paramMobileAd.text().length() / 2;
        int n;
        label161: int i3;
        float f;
        if (m > 18)
        {
          n = 18;
          if (this.textviewH == 0)
          {
            Rect localRect = new Rect();
            this.mAdText.getLineBounds(0, localRect);
            int i1 = this.mAdText.getLineHeight() - 4;
            this.textviewH = i1;
            int i2 = this.mAdText.getWidth();
            this.textviewW = i2;
          }
          i3 = this.textviewW / n;
          TextView localTextView1 = this.mAdText;
          int i4 = this.textviewH;
          if (i3 < i4)
            break label309;
          f = this.textviewH;
          label254: localTextView1.setTextSize(f);
          TextView localTextView3 = this.mAdText;
          String str3 = paramMobileAd.text();
          localTextView3.setText(str3);
          if (localDrawable3 == null)
            break label317;
          this.mTextAdLayout.setBackgroundDrawable(localDrawable3);
        }
        while (true)
        {
          showTextAdLayout();
          j = 1;
          break;
          n = m;
          break label161;
          label309: f = i3;
          break label254;
          label317: RelativeLayout localRelativeLayout = this.mTextAdLayout;
          int i5 = Color.parseColor(this.mAdBackgroundColor);
          localRelativeLayout.setBackgroundColor(i5);
        }
      }
      int j = 0;
    }
  }

  private int pixelFromDp(int paramInt)
  {
    DisplayMetrics localDisplayMetrics = getContext().getResources().getDisplayMetrics();
    float f1 = paramInt;
    float f2 = localDisplayMetrics.density;
    return (int)(f1 * f2);
  }

  private void postTrace()
  {
    if ((this.mTURL != null) && (this.mTURL.length() > 0))
    {
      AdTHttpContext localAdTHttpContext = new AdTHttpContext();
      String str1 = this.mTURL;
      String str2 = this.userAgent;
      localAdTHttpContext.postTrace(str1, str2);
    }
  }

  private void setAttribute(Context paramContext, AttributeSet paramAttributeSet)
  {
    StringBuilder localStringBuilder = new StringBuilder().append("http://schemas.android.com/apk/res/");
    String str1 = getContext().getPackageName();
    String str2 = str1;
    int i = paramAttributeSet.getAttributeIntValue(str2, "refreshInterval", 60);
    setRequestInterval(i);
  }

  private void showBannerAdLayout()
  {
    if ((this.mTextAdLayout == null) || (this.mBannerAdLayout == null) || (this.mHtmlAdLayout == null));
    while (true)
    {
      return;
      this.mBannerAdLayout.setVisibility(0);
      this.mTextAdLayout.setVisibility(4);
      this.mHtmlAdLayout.setVisibility(4);
    }
  }

  private void showHtmlAdLayout()
  {
    if ((this.mTextAdLayout == null) || (this.mBannerAdLayout == null) || (this.mHtmlAdLayout == null));
    while (true)
    {
      return;
      this.mHtmlAdLayout.setVisibility(0);
      this.mTextAdLayout.setVisibility(4);
      this.mBannerAdLayout.setVisibility(4);
    }
  }

  private void showTextAdLayout()
  {
    if ((this.mTextAdLayout == null) || (this.mBannerAdLayout == null) || (this.mHtmlAdLayout == null));
    while (true)
    {
      return;
      this.mTextAdLayout.setVisibility(0);
      this.mBannerAdLayout.setVisibility(4);
      this.mHtmlAdLayout.setVisibility(4);
    }
  }

  private void startClickAction()
  {
    if ((this.mClickURL != null) && (this.mClickURL.length() > 0));
    try
    {
      Uri localUri = Uri.parse(this.mClickURL);
      if (this.mClickURL.startsWith("tel:"));
      Intent localIntent;
      for (Object localObject = new Intent("android.intent.action.DIAL", localUri); ; localObject = localIntent)
      {
        if (localObject != null)
        {
          postTrace();
          getContext().startActivity((Intent)localObject);
        }
        return;
        localIntent = new Intent("android.intent.action.VIEW", localUri);
      }
    }
    catch (Throwable localThrowable)
    {
      while (true)
      {
        StringBuilder localStringBuilder = new StringBuilder().append("click fail:");
        String str1 = this.mClickURL;
        String str2 = str1;
        Log.e("MobileAdView", str2, localThrowable);
      }
    }
  }

  private void updateAdview(MobileAd paramMobileAd)
  {
    int i = 0;
    String str1 = paramMobileAd.type();
    boolean bool;
    if ("T".equals(str1))
    {
      bool = makeTextAdView(paramMobileAd);
      if (!bool)
        break label125;
      String str2 = paramMobileAd.type();
      if (!"H".equals(str2))
      {
        String str3 = paramMobileAd.curl();
        String str4 = paramMobileAd.turl();
        changedAd(str3, str4);
        this.hasAd = 1;
      }
    }
    while (true)
    {
      return;
      String str5 = paramMobileAd.type();
      if ("B".equals(str5))
      {
        bool = makeBannerAdView(paramMobileAd);
        break;
      }
      String str6 = paramMobileAd.type();
      if (!"H".equals(str6))
        break;
      bool = makeHtmlAdView(paramMobileAd);
      break;
      label125: MobileAdSDKError localMobileAdSDKError = MobileAdSDKError.AD_DOWNLOAD_ERROR_FAILTODRAW;
      failedDownloadAd(localMobileAdSDKError, null);
    }
  }

  public void destroy()
  {
    if (this.adRefreshTask != null)
    {
      this.adRefreshTask.destroy();
      this.adRefreshTask = null;
    }
    destroyTextAdLayout();
    destroyBannerAdLayout();
    destroyHtmlAdLasyout();
    this.mClickURL = null;
    this.mTURL = null;
    this.mAdListener = null;
  }

  public void failedDownloadAd(MobileAdSDKError paramMobileAdSDKError, String paramString)
  {
    if (this.mAdListener != null)
    {
      AdHttpListener localAdHttpListener = this.mAdListener;
      int i = paramMobileAdSDKError.ordinal();
      StringBuilder localStringBuilder = new StringBuilder();
      String str1 = paramMobileAdSDKError.toString();
      String str2 = str1 + ":" + paramString;
      localAdHttpListener.failedDownloadAd_AdListener(i, str2);
    }
  }

  protected void finalize()
    throws Throwable
  {
    finalize();
    destroy();
  }

  public AdHttpListener getAdListener()
  {
    return this.mAdListener;
  }

  public int getRequestInterval()
  {
    return this.mRefreshInterval;
  }

  public String getUserAgent()
  {
    return this.userAgent;
  }

  public boolean hasAd()
  {
    return this.hasAd;
  }

  protected void initView()
  {
    if (this.userAgent == null)
    {
      Context localContext = getContext();
      String str1 = new WebView(localContext).getSettings().getUserAgentString();
      this.userAgent = str1;
    }
    StringBuilder localStringBuilder1 = new StringBuilder();
    int i = getWidth();
    StringBuilder localStringBuilder2 = localStringBuilder1.append(i).append(",");
    int j = getHeight();
    String str2 = j;
    AdCommon.debug("MobileAdView", str2);
    initTextAd();
    initBannerAd();
    initHtmlAd();
    this.mTextAdLayout.setVisibility(4);
    this.mBannerAdLayout.setVisibility(4);
    this.mHtmlAdLayout.setVisibility(4);
    MobileAdView.2 local2 = new MobileAdView.2(this);
    this.mTextAdLayout.setOnClickListener(local2);
    this.mBannerAdLayout.setOnClickListener(local2);
    this.mHtmlAdLayout.setOnClickListener(local2);
  }

  public void pause()
  {
    this.adRefreshTask.pause();
  }

  void printVisibility()
  {
    StringBuilder localStringBuilder1 = new StringBuilder().append("mText=");
    int i = this.mTextAdLayout.getVisibility();
    StringBuilder localStringBuilder2 = localStringBuilder1.append(i).append(",mBanner=");
    int j = this.mBannerAdLayout.getVisibility();
    StringBuilder localStringBuilder3 = localStringBuilder2.append(j).append(",mHtml=");
    int k = this.mHtmlAdLayout.getVisibility();
    String str = k;
    Log.e("MobileAdView", str);
  }

  public void resume()
  {
    this.adRefreshTask.resume();
  }

  public void setAdListener(AdHttpListener paramAdHttpListener)
  {
    this.mAdListener = paramAdHttpListener;
    if (paramAdHttpListener == null)
      pause();
    while (true)
    {
      return;
      resume();
    }
  }

  public void setRequestInterval(int paramInt)
  {
    String str = AdCommon.get("appid");
    if ("net.daum.test".equals(str))
      this.mRefreshInterval = paramInt;
    while (true)
    {
      return;
      if (paramInt < 12)
      {
        this.mRefreshInterval = 12;
        continue;
      }
      if (paramInt > 120)
      {
        this.mRefreshInterval = 120;
        continue;
      }
      this.mRefreshInterval = paramInt;
    }
  }

  protected void setUserAgent(String paramString)
  {
    this.userAgent = paramString;
  }
}

/* Location:           C:\dex2jar-0.0.7.4-SNAPSHOT\classes.dex.dex2jar.jar
 * Qualified Name:     net.daum.mobilead.MobileAdView
 * JD-Core Version:    0.6.0
 */